@@ -34,11 +34,13 @@
  * being a canvas. Anyway, this is required for applications using
  * just clutter, or directly #ClutterStage
  */
-#include "config.h"
 
 #include "cally-stage.h"
 #include "cally-actor-private.h"
 
+static void cally_stage_class_init (CallyStageClass *klass);
+static void cally_stage_init       (CallyStage      *stage);
+
 /* AtkObject.h */
 static void                  cally_stage_real_initialize (AtkObject *obj,
                                                           gpointer   data);
@@ -53,35 +55,39 @@ static void                  cally_stage_activate_cb     (ClutterStage *stage,
 static void                  cally_stage_deactivate_cb   (ClutterStage *stage,
                                                           gpointer      data);
 
-struct _CallyStagePrivate
-{
-  /* NULL means that the stage will receive the focus */
-  ClutterActor *key_focus;
-
-  gboolean active;
-};
 
 G_DEFINE_TYPE_WITH_CODE (CallyStage,
                          cally_stage,
                          CALLY_TYPE_GROUP,
-                         G_ADD_PRIVATE (CallyStage)
                          G_IMPLEMENT_INTERFACE (ATK_TYPE_WINDOW,
                                                 cally_stage_window_interface_init));
 
+#define CALLY_STAGE_GET_PRIVATE(obj) \
+  (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CALLY_TYPE_STAGE, CallyStagePrivate))
+
+struct _CallyStagePrivate
+{
+  gboolean active;
+};
+
 static void
 cally_stage_class_init (CallyStageClass *klass)
 {
-  AtkObjectClass *class = ATK_OBJECT_CLASS (klass);
+  GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
+  AtkObjectClass *class         = ATK_OBJECT_CLASS (klass);
+/*   CallyActorClass *cally_class  = CALLY_ACTOR_CLASS (klass); */
 
   /* AtkObject */
   class->initialize = cally_stage_real_initialize;
   class->ref_state_set = cally_stage_ref_state_set;
+
+  g_type_class_add_private (gobject_class, sizeof (CallyStagePrivate));
 }
 
 static void
 cally_stage_init (CallyStage *cally_stage)
 {
-  CallyStagePrivate *priv = cally_stage_get_instance_private (cally_stage);
+  CallyStagePrivate *priv = CALLY_STAGE_GET_PRIVATE (cally_stage);
 
   cally_stage->priv = priv;
 
@@ -115,64 +121,6 @@ cally_stage_new (ClutterActor *actor)
   return accessible;
 }
 
-static void
-cally_stage_notify_key_focus_cb (ClutterStage *stage,
-                                 GParamSpec   *pspec,
-                                 CallyStage   *self)
-{
-  ClutterActor *key_focus = NULL;
-  AtkObject *new = NULL;
-
-  if (self->priv->active == FALSE)
-    return;
-
-  key_focus = clutter_stage_get_key_focus (stage);
-
-  if (key_focus != self->priv->key_focus)
-    {
-      AtkObject *old = NULL;
-
-      if (self->priv->key_focus != NULL)
-        {
-          g_object_remove_weak_pointer (G_OBJECT (self->priv->key_focus),
-                                        (gpointer *) &self->priv->key_focus);
-          old = clutter_actor_get_accessible (self->priv->key_focus);
-        }
-      else
-        old = clutter_actor_get_accessible (CLUTTER_ACTOR (stage));
-
-      atk_object_notify_state_change (old,
-                                      ATK_STATE_FOCUSED,
-                                      FALSE);
-    }
-
-  /* we keep notifying the focus gain without checking previous
-   * key-focus to avoid some missing events due timing
-   */
-  self->priv->key_focus = key_focus;
-
-  if (key_focus != NULL)
-    {
-      /* ensure that if the key focus goes away, the field inside
-       * CallyStage is reset. see bug:
-       *
-       * https://bugzilla.gnome.org/show_bug.cgi?id=692706
-       *
-       * we remove the weak pointer above.
-       */
-      g_object_add_weak_pointer (G_OBJECT (self->priv->key_focus),
-                                 (gpointer *) &self->priv->key_focus);
-
-      new = clutter_actor_get_accessible (key_focus);
-    }
-  else
-    new = clutter_actor_get_accessible (CLUTTER_ACTOR (stage));
-
-  atk_object_notify_state_change (new,
-                                  ATK_STATE_FOCUSED,
-                                  TRUE);
-}
-
 static void
 cally_stage_real_initialize (AtkObject *obj,
                              gpointer  data)
@@ -187,10 +135,8 @@ cally_stage_real_initialize (AtkObject *obj,
 
   g_signal_connect (stage, "activate", G_CALLBACK (cally_stage_activate_cb), obj);
   g_signal_connect (stage, "deactivate", G_CALLBACK (cally_stage_deactivate_cb), obj);
-  g_signal_connect (stage, "notify::key-focus",
-                    G_CALLBACK (cally_stage_notify_key_focus_cb), obj);
 
-  atk_object_set_role (obj, ATK_ROLE_WINDOW);
+  obj->role = ATK_ROLE_CANVAS;
 }
 
 static AtkStateSet*
