@@ -155,14 +155,10 @@ get_units_per_em (ClutterBackend       *backend,
       if (is_absolute)
         font_size = (gdouble) pango_size / PANGO_SCALE;
       else
-        font_size = (gdouble) pango_size / PANGO_SCALE
-                  * dpi
-                  / 96.0f;
+        font_size = dpi * ((gdouble) pango_size / PANGO_SCALE) / 72.0f;
 
       /* 10 points at 96 DPI is 13.3 pixels */
-      units_per_em = (1.2f * font_size)
-                   * dpi
-                   / 96.0f;
+      units_per_em = (1.2f * font_size) * dpi / 96.0f;
     }
   else
     units_per_em = -1.0f;
@@ -179,14 +175,20 @@ clutter_backend_real_resolution_changed (ClutterBackend *backend)
   ClutterBackendPrivate *priv = backend->priv;
   ClutterMainContext *context;
   ClutterSettings *settings;
+  gdouble resolution;
   gint dpi;
 
   settings = clutter_settings_get_default ();
   g_object_get (settings, "font-dpi", &dpi, NULL);
 
+  if (dpi < 0)
+    resolution = 96.0;
+  else
+    resolution = dpi / 1024.0;
+
   context = _clutter_context_get_default ();
   if (context->font_map != NULL)
-    cogl_pango_font_map_set_resolution (context->font_map, dpi / 1024.0);
+    cogl_pango_font_map_set_resolution (context->font_map, resolution);
 
   priv->units_per_em = get_units_per_em (backend, NULL);
   priv->units_serial += 1;
@@ -478,18 +480,18 @@ _clutter_backend_ensure_context (ClutterBackend *backend,
                         new_stage);
         }
 
-      _clutter_backend_ensure_context_internal (backend, new_stage);
-
       /* XXX: Until Cogl becomes fully responsible for backend windows
        * Clutter need to manually keep it informed of the current window size
        *
        * NB: This must be done after we ensure_context above because Cogl
        * always assumes there is a current GL context.
        */
-      if (new_stage)
+      if (new_stage != NULL)
         {
           float width, height;
 
+          _clutter_backend_ensure_context_internal (backend, new_stage);
+
           clutter_actor_get_size (CLUTTER_ACTOR (stage), &width, &height);
 
           cogl_onscreen_clutter_backend_set_size (width, height);
@@ -501,7 +503,8 @@ _clutter_backend_ensure_context (ClutterBackend *backend,
            * switch between stages.
            *
            * This dirty mechanism will ensure they are asserted before
-           * the next paint... */
+           * the next paint...
+           */
           _clutter_stage_dirty_viewport (stage);
           _clutter_stage_dirty_projection (stage);
         }
@@ -509,7 +512,7 @@ _clutter_backend_ensure_context (ClutterBackend *backend,
       /* FIXME: With a NULL stage and thus no active context it may make more
        * sense to clean the context but then re call with the default stage 
        * so at least there is some kind of context in place (as to avoid
-       * potential issue of GL calls with no context)
+       * potential issue of GL calls with no context).
        */
       current_context_stage = new_stage;
     }
@@ -787,6 +790,9 @@ clutter_backend_get_resolution (ClutterBackend *backend)
   settings = clutter_settings_get_default ();
   g_object_get (settings, "font-dpi", &resolution, NULL);
 
+  if (resolution < 0)
+    return 96.0;
+
   return resolution / 1024.0;
 }
 
@@ -968,3 +974,29 @@ _clutter_backend_remove_event_translator (ClutterBackend         *backend,
   priv->event_translators =
     g_list_remove (priv->event_translators, translator);
 }
+
+/**
+ * clutter_backend_get_cogl_context:
+ * @backend: a #ClutterBackend
+ *
+ * Retrieves the #CoglContext associated with the given clutter
+ * @backend. A #CoglContext is required when using some of the
+ * experimental 2.0 Cogl API.
+ *
+ * <note>Since CoglContext is itself experimental API this API should
+ * be considered experimental too.</note>
+ *
+ * <note>This API is not yet supported on OSX because OSX still
+ * uses the stub Cogl winsys and the Clutter backend doesn't
+ * explicitly create a CoglContext.</note>
+ *
+ * Return value: The #CoglContext associated with @backend.
+ *
+ * Since: 1.8
+ * Stability: unstable
+ */
+CoglContext *
+clutter_backend_get_cogl_context (ClutterBackend *backend)
+{
+  return backend->cogl_context;
+}
