@@ -29,16 +29,60 @@
  * #ClutterBinLayout is a layout manager which implements the following
  * policy:
  *
- *   - the preferred size is the maximum preferred size
+ * <itemizedlist>
+ *   <listitem><simpara>the preferred size is the maximum preferred size
  *   between all the children of the container using the
- *   layout;
- *   - each child is allocated in "layers", on on top
- *   of the other;
- *   - for each layer there are horizontal and vertical
- *   alignment policies.
+ *   layout;</simpara></listitem>
+ *   <listitem><simpara>each child is allocated in "layers", on on top
+ *   of the other;</simpara></listitem>
+ *   <listitem><simpara>for each layer there are horizontal and vertical
+ *   alignment policies.</simpara></listitem>
+ * </itemizedlist>
  *
- * The [bin-layout example](https://git.gnome.org/browse/clutter/tree/examples/bin-layout.c?h=clutter-1.18)
- * shows how to pack actors inside a #ClutterBinLayout.
+ * <figure id="bin-layout">
+ *   <title>Bin layout</title>
+ *   <para>The image shows a #ClutterBinLayout with three layers:
+ *   a background #ClutterCairoTexture, set to fill on both the X
+ *   and Y axis; a #ClutterTexture, set to center on both the X and
+ *   Y axis; and a #ClutterRectangle, set to %CLUTTER_BIN_ALIGNMENT_END
+ *   on both the X and Y axis.</para>
+ *   <graphic fileref="bin-layout.png" format="PNG"/>
+ * </figure>
+ *
+ * <example id="example-clutter-bin-layout">
+ *  <title>How to pack actors inside a BinLayout</title>
+ *  <para>The following code shows how to build a composite actor with
+ *  a texture and a background, and add controls overlayed on top. The
+ *  background is set to fill the whole allocation, whilst the texture
+ *  is centered; there is a control in the top right corner and a label
+ *  in the bottom, filling out the whole allocated width.</para>
+ *  <programlisting>
+ *  ClutterLayoutManager *manager;
+ *  ClutterActor *box;
+ *
+ *  /&ast; create the layout first &ast;/
+ *  layout = clutter_bin_layout_new (CLUTTER_BIN_ALIGNMENT_CENTER,
+ *                                   CLUTTER_BIN_ALIGNMENT_CENTER);
+ *  box = clutter_box_new (layout); /&ast; then the container &ast;/
+ *
+ *  /&ast; we can use the layout object to add actors &ast;/
+ *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), background,
+ *                          CLUTTER_BIN_ALIGNMENT_FILL,
+ *                          CLUTTER_BIN_ALIGNMENT_FILL);
+ *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), icon,
+ *                          CLUTTER_BIN_ALIGNMENT_CENTER,
+ *                          CLUTTER_BIN_ALIGNMENT_CENTER);
+ *
+ *  /&ast; align to the bottom left &ast;/
+ *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), label,
+ *                          CLUTTER_BIN_ALIGNMENT_START,
+ *                          CLUTTER_BIN_ALIGNMENT_END);
+ *  /&ast; align to the top right &ast;/
+ *  clutter_bin_layout_add (CLUTTER_BIN_LAYOUT (layout), button,
+ *                          CLUTTER_BIN_ALIGNMENT_END,
+ *                          CLUTTER_BIN_ALIGNMENT_START);
+ *  </programlisting>
+ * </example>
  *
  * #ClutterBinLayout is available since Clutter 1.2
  */
@@ -49,12 +93,9 @@
 
 #include <math.h>
 
-#define CLUTTER_DISABLE_DEPRECATION_WARNINGS
-#include "deprecated/clutter-container.h"
-#include "deprecated/clutter-bin-layout.h"
-
-#include "clutter-actor-private.h"
+#include "clutter-actor.h"
 #include "clutter-animatable.h"
+#include "clutter-bin-layout.h"
 #include "clutter-child-meta.h"
 #include "clutter-debug.h"
 #include "clutter-enum-types.h"
@@ -65,6 +106,8 @@
 #define CLUTTER_BIN_LAYER(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLUTTER_TYPE_BIN_LAYER, ClutterBinLayer))
 #define CLUTTER_IS_BIN_LAYER(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLUTTER_TYPE_BIN_LAYER))
 
+#define CLUTTER_BIN_LAYOUT_GET_PRIVATE(obj)     (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_BIN_LAYOUT, ClutterBinLayoutPrivate))
+
 typedef struct _ClutterBinLayer         ClutterBinLayer;
 typedef struct _ClutterLayoutMetaClass  ClutterBinLayerClass;
 
@@ -107,15 +150,13 @@ enum
 static GParamSpec *layer_props[PROP_LAYER_LAST] = { NULL, };
 static GParamSpec *bin_props[PROP_LAST] = { NULL, };
 
-GType clutter_bin_layer_get_type (void);
-
 G_DEFINE_TYPE (ClutterBinLayer,
                clutter_bin_layer,
-               CLUTTER_TYPE_LAYOUT_META)
+               CLUTTER_TYPE_LAYOUT_META);
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterBinLayout,
-                            clutter_bin_layout,
-                            CLUTTER_TYPE_LAYOUT_MANAGER)
+G_DEFINE_TYPE (ClutterBinLayout,
+               clutter_bin_layout,
+               CLUTTER_TYPE_LAYOUT_MANAGER);
 
 /*
  * ClutterBinLayer
@@ -294,21 +335,17 @@ clutter_bin_layout_get_preferred_width (ClutterLayoutManager *manager,
                                         gfloat               *min_width_p,
                                         gfloat               *nat_width_p)
 {
-  ClutterActor *actor = CLUTTER_ACTOR (container);
-  ClutterActorIter iter;
-  ClutterActor *child;
+  GList *children = clutter_container_get_children (container);
+  GList *l;
   gfloat min_width, nat_width;
 
   min_width = nat_width = 0.0;
 
-  clutter_actor_iter_init (&iter, actor);
-  while (clutter_actor_iter_next (&iter, &child))
+  for (l = children; l != NULL; l = l->next)
     {
+      ClutterActor *child = l->data;
       gfloat minimum, natural;
 
-      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
-        continue;
-
       clutter_actor_get_preferred_width (child, for_height,
                                          &minimum,
                                          &natural);
@@ -322,6 +359,8 @@ clutter_bin_layout_get_preferred_width (ClutterLayoutManager *manager,
 
   if (nat_width_p)
     *nat_width_p = nat_width;
+
+  g_list_free (children);
 }
 
 static void
@@ -331,21 +370,17 @@ clutter_bin_layout_get_preferred_height (ClutterLayoutManager *manager,
                                          gfloat               *min_height_p,
                                          gfloat               *nat_height_p)
 {
-  ClutterActor *actor = CLUTTER_ACTOR (container);
-  ClutterActorIter iter;
-  ClutterActor *child;
+  GList *children = clutter_container_get_children (container);
+  GList *l;
   gfloat min_height, nat_height;
 
   min_height = nat_height = 0.0;
 
-  clutter_actor_iter_init (&iter, actor);
-  while (clutter_actor_iter_next (&iter, &child))
+  for (l = children; l != NULL; l = l->next)
     {
+      ClutterActor *child = l->data;
       gfloat minimum, natural;
 
-      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
-        continue;
-
       clutter_actor_get_preferred_height (child, for_width,
                                           &minimum,
                                           &natural);
@@ -359,11 +394,12 @@ clutter_bin_layout_get_preferred_height (ClutterLayoutManager *manager,
 
   if (nat_height_p)
     *nat_height_p = nat_height;
+
+  g_list_free (children);
 }
 
 static gdouble
-get_bin_alignment_factor (ClutterBinAlignment alignment,
-                          ClutterTextDirection text_dir)
+get_bin_alignment_factor (ClutterBinAlignment alignment)
 {
   switch (alignment)
     {
@@ -371,10 +407,10 @@ get_bin_alignment_factor (ClutterBinAlignment alignment,
       return 0.5;
 
     case CLUTTER_BIN_ALIGNMENT_START:
-      return text_dir == CLUTTER_TEXT_DIRECTION_LTR ? 0.0 : 1.0;
+      return 0.0;
 
     case CLUTTER_BIN_ALIGNMENT_END:
-      return text_dir == CLUTTER_TEXT_DIRECTION_LTR ? 1.0 : 0.0;
+      return 1.0;
 
     case CLUTTER_BIN_ALIGNMENT_FIXED:
     case CLUTTER_BIN_ALIGNMENT_FILL:
@@ -384,142 +420,59 @@ get_bin_alignment_factor (ClutterBinAlignment alignment,
   return 0.0;
 }
 
-static gdouble
-get_actor_align_factor (ClutterActorAlign alignment)
-{
-  switch (alignment)
-    {
-    case CLUTTER_ACTOR_ALIGN_CENTER:
-      return 0.5;
-
-    case CLUTTER_ACTOR_ALIGN_START:
-      return 0.0;
-
-    case CLUTTER_ACTOR_ALIGN_END:
-      return 1.0;
-
-    case CLUTTER_ACTOR_ALIGN_FILL:
-      return 0.0;
-    }
-
-  return 0.0;
-}
-
 static void
 clutter_bin_layout_allocate (ClutterLayoutManager   *manager,
                              ClutterContainer       *container,
                              const ClutterActorBox  *allocation,
                              ClutterAllocationFlags  flags)
 {
+  GList *children = clutter_container_get_children (container);
+  GList *l;
   gfloat allocation_x, allocation_y;
   gfloat available_w, available_h;
-  ClutterActor *actor, *child;
-  ClutterActorIter iter;
 
   clutter_actor_box_get_origin (allocation, &allocation_x, &allocation_y);
   clutter_actor_box_get_size (allocation, &available_w, &available_h);
 
-  actor = CLUTTER_ACTOR (container);
-
-  clutter_actor_iter_init (&iter, actor);
-  while (clutter_actor_iter_next (&iter, &child))
+  for (l = children; l != NULL; l = l->next)
     {
+      ClutterActor *child = l->data;
       ClutterLayoutMeta *meta;
       ClutterBinLayer *layer;
       ClutterActorBox child_alloc = { 0, };
       gdouble x_align, y_align;
-      gboolean x_fill, y_fill, is_fixed_position_set;
-      float fixed_x, fixed_y;
-
-      if (!CLUTTER_ACTOR_IS_VISIBLE (child))
-        continue;
+      gboolean x_fill, y_fill;
 
       meta = clutter_layout_manager_get_child_meta (manager,
                                                     container,
                                                     child);
       layer = CLUTTER_BIN_LAYER (meta);
 
-      fixed_x = fixed_y = 0.f;
-      g_object_get (child,
-                    "fixed-position-set", &is_fixed_position_set,
-                    "fixed-x", &fixed_x,
-                    "fixed-y", &fixed_y,
-                    NULL);
-
-      /* XXX:2.0 - remove the FIXED alignment, and just use the fixed position
-       * of the actor if one is set
-       */
-      if (is_fixed_position_set ||
-          layer->x_align == CLUTTER_BIN_ALIGNMENT_FIXED)
-	{
-          if (is_fixed_position_set)
-            child_alloc.x1 = fixed_x;
-          else
-            child_alloc.x1 = clutter_actor_get_x (child);
-	}
+      if (layer->x_align == CLUTTER_BIN_ALIGNMENT_FIXED)
+        child_alloc.x1 = clutter_actor_get_x (child);
       else
         child_alloc.x1 = allocation_x;
 
-      if (is_fixed_position_set ||
-          layer->y_align == CLUTTER_BIN_ALIGNMENT_FIXED)
-	{
-	  if (is_fixed_position_set)
-            child_alloc.y1 = fixed_y;
-          else
-	    child_alloc.y1 = clutter_actor_get_y (child);
-	}
+      if (layer->y_align == CLUTTER_BIN_ALIGNMENT_FIXED)
+        child_alloc.y1 = clutter_actor_get_y (child);
       else
         child_alloc.y1 = allocation_y;
 
-      child_alloc.x2 = allocation_x + available_w;
-      child_alloc.y2 = allocation_y + available_h;
+      child_alloc.x2 = available_w;
+      child_alloc.y2 = available_h;
 
-      if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_HORIZONTAL))
-        {
-          ClutterActorAlign align;
-
-          align = clutter_actor_get_x_align (child);
-          x_fill = align == CLUTTER_ACTOR_ALIGN_FILL;
-          x_align = get_actor_align_factor (align);
-        }
-      else
-        {
-          ClutterTextDirection text_dir;
-
-          x_fill = (layer->x_align == CLUTTER_BIN_ALIGNMENT_FILL);
-
-          text_dir = clutter_actor_get_text_direction (child);
-
-          if (!is_fixed_position_set)
-            x_align = get_bin_alignment_factor (layer->x_align, text_dir);
-          else
-            x_align = 0.0;
-        }
-
-      if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_VERTICAL))
-        {
-          ClutterActorAlign align;
-
-          align = clutter_actor_get_y_align (child);
-          y_fill = align == CLUTTER_ACTOR_ALIGN_FILL;
-          y_align = get_actor_align_factor (align);
-        }
-      else
-        {
-          y_fill = (layer->y_align == CLUTTER_BIN_ALIGNMENT_FILL);
-
-          if (!is_fixed_position_set)
-            y_align = get_bin_alignment_factor (layer->y_align,
-                                                CLUTTER_TEXT_DIRECTION_LTR);
-          else
-            y_align = 0.0;
-        }
+      x_fill = (layer->x_align == CLUTTER_BIN_ALIGNMENT_FILL);
+      y_fill = (layer->y_align == CLUTTER_BIN_ALIGNMENT_FILL);
+      x_align = get_bin_alignment_factor (layer->x_align);
+      y_align = get_bin_alignment_factor (layer->y_align);
 
       clutter_actor_allocate_align_fill (child, &child_alloc,
                                          x_align, y_align,
                                          x_fill, y_fill,
                                          flags);
     }
+
+  g_list_free (children);
 }
 
 static GType
@@ -617,6 +570,8 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
   ClutterLayoutManagerClass *layout_class =
     CLUTTER_LAYOUT_MANAGER_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (ClutterBinLayoutPrivate));
+
   /**
    * ClutterBinLayout:x-align:
    *
@@ -624,9 +579,6 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
    * by the #ClutterBinLayout
    *
    * Since: 1.2
-   *
-   * Deprecated: 1.12: Use the #ClutterActor:x-expand and the
-   *   #ClutterActor:x-align properties on #ClutterActor instead.
    */
   bin_props[PROP_X_ALIGN] =
     g_param_spec_enum ("x-align",
@@ -644,9 +596,6 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
    * by the #ClutterBinLayout
    *
    * Since: 1.2
-   *
-   * Deprecated: 1.12: Use the #ClutterActor:y-expand and the
-   *   #ClutterActor:y-align properties on #ClutterActor instead.
    */
   bin_props[PROP_Y_ALIGN] =
     g_param_spec_enum ("y-align",
@@ -659,20 +608,28 @@ clutter_bin_layout_class_init (ClutterBinLayoutClass *klass)
 
   gobject_class->set_property = clutter_bin_layout_set_property;
   gobject_class->get_property = clutter_bin_layout_get_property;
-  g_object_class_install_properties (gobject_class, PROP_LAST, bin_props);
+  g_object_class_install_properties (gobject_class,
+                                     PROP_LAST,
+                                     bin_props);
 
-  layout_class->get_preferred_width = clutter_bin_layout_get_preferred_width;
-  layout_class->get_preferred_height = clutter_bin_layout_get_preferred_height;
-  layout_class->allocate = clutter_bin_layout_allocate;
-  layout_class->create_child_meta = clutter_bin_layout_create_child_meta;
-  layout_class->get_child_meta_type = clutter_bin_layout_get_child_meta_type;
-  layout_class->set_container = clutter_bin_layout_set_container;
+  layout_class->get_preferred_width =
+    clutter_bin_layout_get_preferred_width;
+  layout_class->get_preferred_height =
+    clutter_bin_layout_get_preferred_height;
+  layout_class->allocate =
+    clutter_bin_layout_allocate;
+  layout_class->create_child_meta =
+    clutter_bin_layout_create_child_meta;
+  layout_class->get_child_meta_type =
+    clutter_bin_layout_get_child_meta_type;
+  layout_class->set_container =
+    clutter_bin_layout_set_container;
 }
 
 static void
 clutter_bin_layout_init (ClutterBinLayout *self)
 {
-  self->priv = clutter_bin_layout_get_instance_private (self);
+  self->priv = CLUTTER_BIN_LAYOUT_GET_PRIVATE (self);
 
   self->priv->x_align = CLUTTER_BIN_ALIGNMENT_CENTER;
   self->priv->y_align = CLUTTER_BIN_ALIGNMENT_CENTER;
@@ -717,9 +674,6 @@ clutter_bin_layout_new (ClutterBinAlignment x_align,
  * be set as the default alignment policies
  *
  * Since: 1.2
- *
- * Deprecated: 1.12: Use the #ClutterActor:x-align and
- *   #ClutterActor:y-align properties of #ClutterActor instead.
  */
 void
 clutter_bin_layout_set_alignment (ClutterBinLayout    *self,
@@ -778,9 +732,6 @@ clutter_bin_layout_set_alignment (ClutterBinLayout    *self,
  * instead
  *
  * Since: 1.2
- *
- * Deprecated: 1.12: Use the #ClutterActor:x-align and the
- *   #ClutterActor:y-align properties of #ClutterActor instead.
  */
 void
 clutter_bin_layout_get_alignment (ClutterBinLayout    *self,
@@ -847,8 +798,6 @@ clutter_bin_layout_get_alignment (ClutterBinLayout    *self,
  * #ClutterBinLayout
  *
  * Since: 1.2
- *
- * Deprecated: 1.12: Use clutter_actor_add_child() instead.
  */
 void
 clutter_bin_layout_add (ClutterBinLayout    *self,
